==> hadoop-apache2-2.7.4-9-sources.jar: com/facebook/presto/hadoop/$internal/io/netty/handler/codec/compression/DecompressionException.java <==
/*
 * Copyright 2012 The Netty Project
 *
 * The Netty Project licenses this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */
package com.facebook.presto.hadoop.$internal.io.netty.handler.codec.compression;

import com.facebook.presto.hadoop.$internal.io.netty.handler.codec.DecoderException;

/**
 * A {@link DecoderException} that is raised when decompression failed.
 */
public class DecompressionException extends DecoderException {

    private static final long serialVersionUID = 3546272712208105199L;

    /**
     * Creates a new instance.
     */
    public DecompressionException() {
    }

    /**
     * Creates a new instance.
     */
    public DecompressionException(String message, Throwable cause) {
        super(message, cause);
    }

    /**
     * Creates a new instance.
     */
    public DecompressionException(String message) {
        super(message);
    }

    /**
     * Creates a new instance.
     */
    public DecompressionException(Throwable cause) {
        super(cause);
    }
}

==> hadoop-apache-3.4.1-1-sources.jar: com/facebook/presto/hadoop/$internal/io/netty/handler/codec/compression/DecompressionException.java <==
/*
 * Copyright 2012 The Netty Project
 *
 * The Netty Project licenses this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */
package com.facebook.presto.hadoop.\$internal.io.netty.handler.codec.compression;

import com.facebook.presto.hadoop.\$internal.io.netty.handler.codec.DecoderException;

/**
 * A {@link DecoderException} that is raised when decompression failed.
 */
public class DecompressionException extends DecoderException {

    private static final long serialVersionUID = 3546272712208105199L;

    /**
     * Creates a new instance.
     */
    public DecompressionException() {
    }

    /**
     * Creates a new instance.
     */
    public DecompressionException(String message, Throwable cause) {
        super(message, cause);
    }

    /**
     * Creates a new instance.
     */
    public DecompressionException(String message) {
        super(message);
    }

    /**
     * Creates a new instance.
     */
    public DecompressionException(Throwable cause) {
        super(cause);
    }
}
